# eric7.WebBrowser.SafeBrowsing

Package implementing the safe browsing functionality.

### Modules

SafeBrowsingAPIClient | Module implementing the low level interface for Google Safe Browsing.
SafeBrowsingCache | Module implementing a cache for Google Safe Browsing.
SafeBrowsingDialog | Module implementing a dialog to configure safe browsing support.
SafeBrowsingInfoWidget | Module implementing a widget to show some threat information.
SafeBrowsingLabel | Module implementing the label to show some SSL info.
SafeBrowsingManager | Module implementing the interface for Google Safe Browsing.
SafeBrowsingThreatList | Module implementing the threat list info class.
SafeBrowsingUrl | Module implementing an URL representation suitable for Google Safe Browsing.
SafeBrowsing | Package implementing the safe browsing functionality.